@@ -2,8 +2,8 @@
 from typing import List
 from typing import NewType
 
-from pyutmodel.PyutLink import PyutLink
+from pyutmodel.PyutField import PyutField
+from pyutmodel.PyutMethod import PyutMethod
 
-PyutLinks    = NewType('PyutLinks', List[PyutLink])
 ClassName    = NewType('ClassName', str)
 Implementors = NewType('Implementors', List[ClassName])
