@@ -3,7 +3,8 @@ from enum import Enum
 
 class PyutStereotype(Enum):
     """
-    Class Stereotype
+    Stereotype Enumeration
+    https://www.ibm.com/docs/en/rational-soft-arch/9.5?topic=elements-uml-model-element-stereotypes
     """
     AUXILIARY            = 'auxiliary'
     FOCUS                = 'focus'
@@ -11,17 +12,25 @@ class PyutStereotype(Enum):
     METACLASS            = 'metaclass'
     TYPE                 = 'type'
     UTILITY              = 'utility'
+    NO_STEREOTYPE        = 'noStereotype'
 
     @classmethod
     def toEnum(cls, strValue: str) -> 'PyutStereotype':
         """
         Converts the input string to the appropriate stereotype
+
         Args:
             strValue:   A string value
-        Returns:  The stereotype enumeration
+
+        Returns:  The stereotype enumeration;  Empty strings, multi-spaces strings, & None
+        values return PyutStereotype.NO_STEREOTYPE
         """
-        canonicalStr: str            = strValue.strip(' ').lower()
-        stereotype:   PyutStereotype = PyutStereotype.TYPE
+        stereotype:   PyutStereotype = PyutStereotype.NO_STEREOTYPE
+        if strValue is None:
+            canonicalStr: str = ''  # Force None
+        else:
+            canonicalStr = strValue.strip(' ')  # I want exact match
+
         match canonicalStr:
             case PyutStereotype.AUXILIARY.value:
                 stereotype = PyutStereotype.AUXILIARY
@@ -35,7 +44,11 @@ class PyutStereotype(Enum):
                 stereotype = PyutStereotype.TYPE
             case PyutStereotype.UTILITY.value:
                 stereotype = PyutStereotype.UTILITY
+            case PyutStereotype.NO_STEREOTYPE.value:
+                stereotype = PyutStereotype.NO_STEREOTYPE
+            case '':
+                pass    # No stereotype
             case _:
-                print(f'Warning: did not recognize this  stereotype: {canonicalStr}')
+                print(f'Warning: did not recognize this  stereotype string: `{canonicalStr}`')
 
         return stereotype
